@@ -9,7 +9,10 @@ use assert_cmd::assert::OutputAssertExt;
 #[test]
 fn symbols() -> anyhow::Result<()> {
     // Make sure the library is built.
-    Command::new("cargo").arg("build").ok()?;
+    let skip_build_library = env::var("TEST_DONT_BUILD_LIB").is_ok();
+    if ! skip_build_library {
+        Command::new("cargo").arg("build").ok()?;
+    }
 
     // We want the location of the build directory (e.g.,
     // `/tmp/rpm-sequoia/debug`).
